@@ -258,12 +258,12 @@ query_connection_info (const gchar *dsn, const gchar *user, const gchar *passwor
 	gboolean    retval = FALSE;
 
 	/* FIXME: pass a pointer to parent window */
-	dialog = gtk_dialog_new_with_buttons(_("Database Connection"),
-					     NULL,
-					     GTK_DIALOG_MODAL,
-					     GNM_STOCK_OK, GTK_RESPONSE_ACCEPT,
-					     GNM_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-					     NULL);
+	dialog = gtk_dialog_new_with_buttons (_("Database Connection"),
+					      NULL,
+					      GTK_DIALOG_MODAL,
+					      GNM_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					      GNM_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+					      NULL);
 
 	login = gdaui_login_new (NULL);
 
@@ -327,7 +327,7 @@ open_connection (const gchar *dsn, const gchar *user, const gchar *password, Gda
 		gchar *chosen_dsn = NULL, *auth_string = NULL;
 
 		if (query_connection_info (dsn, user, password, &chosen_dsn, &auth_string) && chosen_dsn) {
-			cnc = gda_connection_open_from_dsn (chosen_dsn, auth_string, options, &error);
+			cnc = gda_connection_open_from_dsn_name (chosen_dsn, auth_string, options, &error);
 			if (!cnc) {
 				g_warning ("Libgda error: %s\n", error->message);
 				g_error_free (error);
@@ -360,7 +360,7 @@ static GnmValue *
 conn_error (GnmFuncEvalInfo *ei, const gchar *dsn_name)
 {
 	gchar    *tmp = g_strdup_printf (_("Error: could not open connection to %s"), dsn_name);
-	GnmValue *ret = value_new_error(ei->pos, tmp);
+	GnmValue *ret = value_new_error (ei->pos, tmp);
 	g_free (tmp);
 	return ret;
 }
