@@ -68,7 +68,7 @@ static GtkTargetEntry const drag_types_out[] = {
 static gboolean
 gnm_pane_guru_key (WBCGtk const *wbcg, GdkEvent *event)
 {
-	GtkWidget *entry, *guru = wbc_gtk_get_guru (wbcg);
+	GtkWidget *entry, *guru = wbcg_get_guru (wbcg);
 
 	if (guru == NULL)
 		return FALSE;
@@ -148,8 +148,8 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *kevent,
 	SheetView *sv = sc->view;
 	Sheet *sheet = sv->sheet;
 	WBCGtk *wbcg = scg->wbcg;
-	WorkbookControl * wbc = scg_wbc(scg);
-	Workbook * wb = wb_control_get_workbook(wbc);
+	WorkbookControl * wbc = scg_wbc (scg);
+	Workbook * wb = wb_control_get_workbook (wbc);
 	gboolean delayed_movement = FALSE;
 	gboolean jump_to_bounds;
 	gboolean is_enter = FALSE;
@@ -585,7 +585,7 @@ gnm_pane_key_press (GtkWidget *widget, GdkEventKey *event)
 	/* Object manipulation */
 	if (scg->selected_objects != NULL ||
 	     scg->wbcg->new_object != NULL) {
-		if (wbc_gtk_get_guru (scg->wbcg) == NULL &&
+		if (wbcg_get_guru (scg->wbcg) == NULL &&
 		    gnm_pane_object_key_press (pane, event))
 			return TRUE;
 	}
@@ -661,12 +661,16 @@ gnm_pane_focus_out (GtkWidget *widget, GdkEventFocus *event)
 static void
 gnm_pane_realize (GtkWidget *w)
 {
+	GnmPane *pane = GNM_PANE (w);
+
 	if (GTK_WIDGET_CLASS (parent_klass)->realize)
 		(*GTK_WIDGET_CLASS (parent_klass)->realize) (w);
 
 	gtk_im_context_set_client_window
-		(GNM_PANE (w)->im_context,
+		(pane->im_context,
 		 gtk_widget_get_window (gtk_widget_get_toplevel (w)));
+
+	g_hash_table_remove_all (pane->object_style);
 }
 
 static void
@@ -818,14 +822,18 @@ cb_pane_init_objs (GnmPane *pane)
 	GSList *ptr, *list;
 
 	if (sheet != NULL) {
+		sheet_freeze_object_views (sheet, TRUE);
+
 		/* List is stored in reverse stacking order.  Top of stack is
-		 * first.  On creation new foocanvas item get added to
+		 * first.  On creation new canvas item get added to
 		 * the front, so we need to create the views in reverse order */
 		list = g_slist_reverse (g_slist_copy (sheet->sheet_objects));
 		for (ptr = list; ptr != NULL ; ptr = ptr->next)
 			sheet_object_new_view (ptr->data,
 				(SheetObjectViewContainer *)pane);
 		g_slist_free (list);
+
+		sheet_freeze_object_views (sheet, FALSE);
 	}
 }
 
@@ -898,9 +906,21 @@ gnm_pane_dispose (GObject *obj)
 	pane->size_guide.start = NULL;
 	pane->size_guide.points = NULL;
 
+	if (pane->object_style) {
+		g_hash_table_destroy (pane->object_style);
+		pane->object_style = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_klass)->dispose (obj);
 }
 
+static void
+cb_unset_free (GValue *value)
+{
+	g_value_unset (value);
+	g_free (value);
+}
+
 static void
 gnm_pane_init (GnmPane *pane)
 {
@@ -940,6 +960,10 @@ gnm_pane_init (GnmPane *pane)
 	pane->preedit_attrs    = NULL;
 	pane->im_preedit_started = FALSE;
 
+	pane->object_style = g_hash_table_new_full
+		(g_str_hash, g_str_equal,
+		 g_free, (GDestroyNotify)cb_unset_free);
+
 	gtk_widget_set_can_focus (GTK_WIDGET (canvas), TRUE);
 	gtk_widget_set_can_default (GTK_WIDGET (canvas), TRUE);
 
@@ -1284,7 +1308,7 @@ gnm_pane_new (SheetControlGUI *scg,
  * @x: In canvas coords
  * @col_origin: optionally return the canvas coord of the col
  *
- * Returns the column containing canvas coord @x
+ * Returns: the column containing canvas coord @x
  **/
 int
 gnm_pane_find_col (GnmPane const *pane, gint64 x, gint64 *col_origin)
@@ -1334,7 +1358,7 @@ gnm_pane_find_col (GnmPane const *pane, gint64 x, gint64 *col_origin)
  * @y: In canvas coords
  * @row_origin: optionally return the canvas coord of the row
  *
- * Returns the column containing canvas coord @y
+ * Returns: the column containing canvas coord @y
  **/
 int
 gnm_pane_find_row (GnmPane const *pane, gint64 y, gint64 *row_origin)
@@ -1524,11 +1548,11 @@ gnm_pane_redraw_range (GnmPane *pane, GnmRange const *r)
 	x2 = (tmp.end.col < gnm_sheet_get_last_col (sheet))
 		? 4 + 1 + x1 + scg_colrow_distance_get (scg, TRUE,
 							tmp.start.col, tmp.end.col+1)
-		: G_MAXINT64;
+		: GNM_CANVAS_INF;
 	y2 = (tmp.end.row < gnm_sheet_get_last_row (sheet))
 		? 4 + 1 + y1 + scg_colrow_distance_get (scg, FALSE,
 							tmp.start.row, tmp.end.row+1)
-		: G_MAXINT64;
+		: GNM_CANVAS_INF;
 
 	goc_canvas_invalidate (&pane->simple.canvas, (x1-2) / scale, (y1-2) / scale, x2 / scale, y2 / scale);
 }
