@@ -505,7 +505,7 @@ gnumeric_popup_menu (GtkMenu *menu, GdkEvent *event)
 	gtk_menu_popup (menu, NULL, NULL, NULL, NULL, 0,
 			(event
 			 ? gdk_event_get_time (event)
-			 : gtk_get_current_event_time()));
+			 : gtk_get_current_event_time ()));
 }
 
 static void
@@ -880,7 +880,7 @@ entry_to_float_with_format_default (GtkEntry *entry, gnm_float *the_float,
 
 	if (!need_default) {
 		char *new_text = g_strdup (text);
-		need_default = (0 ==  strlen (g_strstrip(new_text)));
+		need_default = (0 ==  strlen (g_strstrip (new_text)));
 		g_free (new_text);
 	}
 
@@ -907,7 +907,13 @@ entry_to_float_with_format (GtkEntry *entry, gnm_float *the_float,
 
 	*the_float = value_get_as_float (value);
 	if (update) {
-		char *tmp = format_value (format, value, 16, NULL);
+		char *tmp;
+
+		if (!format || go_format_is_general (format))
+			tmp = value_get_as_string (value);
+		else
+			tmp = format_value (format, value, -1, NULL);
+
 		gtk_entry_set_text (entry, tmp);
 		g_free (tmp);
 	}
@@ -962,7 +968,7 @@ float_to_entry (GtkEntry *entry, gnm_float the_float)
 {
 	GnmValue *val = value_new_float (the_float);
 	char *text = format_value (NULL, val, 16, NULL);
-	value_release(val);
+	value_release (val);
 	if (text != NULL) {
 		gtk_entry_set_text (entry, text);
 		g_free (text);
@@ -981,7 +987,7 @@ int_to_entry (GtkEntry *entry, gint the_int)
 {
 	GnmValue *val  = value_new_int (the_int);
 	char *text = format_value (NULL, val, 16, NULL);
-	value_release(val);
+	value_release (val);
 	if (text != NULL) {
 		gtk_entry_set_text (entry, text);
 		g_free (text);
