@@ -8,5 +8,7 @@ use GnumericTest;
 # See test_importer comments for mode definitions.
 my $mode = ((shift @ARGV) || "check");
 
+my $args = { 'mode' => $mode };
+
 &message ("Check the guppi graph importer.");
-&test_importer ("$samples/b66666-guppi.gnumeric", "e7d2f225b9fc36dae36291d4d2fa848d39e7b006", $mode);
+&test_importer ("$samples/b66666-guppi.gnumeric", "d0457bcfae1b295a97aaae46357ffe0829b6935f", $args);
